==> webkit2gtk_2.16.3.orig.tar.xz: webkitgtk-2.16.3/Source/JavaScriptCore/API/tests/GlobalContextWithFinalizerTest.cpp <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "GlobalContextWithFinalizerTest.h"

#include "JavaScriptCore.h"

static bool failed = true;

static void finalize(JSObjectRef)
{
    failed = false;
}

int testGlobalContextWithFinalizer()
{
    JSClassDefinition def = kJSClassDefinitionEmpty;
    def.className = "testClass";
    def.finalize = finalize;
    JSClassRef classRef = JSClassCreate(&def);
    
    JSGlobalContextRef ref = JSGlobalContextCreateInGroup(nullptr, classRef);
    JSGlobalContextRelease(ref);
    JSClassRelease(classRef);

    if (failed)
        printf("FAIL: JSGlobalContextRef did not call its JSClassRef finalizer.\n");
    else
        printf("PASS: JSGlobalContextRef called its JSClassRef finalizer as expected.\n");

    return failed;
}

==> webkit2gtk_2.44.2.orig.tar.xz: webkitgtk-2.44.2/Source/JavaScriptCore/API/tests/GlobalContextWithFinalizerTest.cpp <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "GlobalContextWithFinalizerTest.h"

#include "JavaScript.h"
#include <stdio.h>

static bool failed = true;

static void finalize(JSObjectRef)
{
    failed = false;
}

int testGlobalContextWithFinalizer()
{
    JSClassDefinition def = kJSClassDefinitionEmpty;
    def.className = "testClass";
    def.finalize = finalize;
    JSClassRef classRef = JSClassCreate(&def);
    
    JSGlobalContextRef ref = JSGlobalContextCreateInGroup(nullptr, classRef);
    JSGlobalContextRelease(ref);
    JSClassRelease(classRef);

    if (failed)
        printf("FAIL: JSGlobalContextRef did not call its JSClassRef finalizer.\n");
    else
        printf("PASS: JSGlobalContextRef called its JSClassRef finalizer as expected.\n");

    return failed;
}
